pub enum RomerStatistic {
Mean,
FloorMean,
Mean50,
}Expand description
Set-level summary statistic for romer (romer’s set.statistic).
Variants
Mean
"mean" (default): mean rank of the moderated t over the set.
FloorMean
"floormean": mean rank after flooring the statistic (separate
non-negative ranks for up, down and mixed directions).
Mean50
"mean50": mean of the more extreme half of the within-set ranks.