pub struct PrinterLayout {
pub ngrid_r: usize,
pub ngrid_c: usize,
pub nspot_r: usize,
pub nspot_c: usize,
}Expand description
Print-tip layout: ngrid_r * ngrid_c tip groups, each printing
nspot_r * nspot_c spots. Spots are laid out as contiguous row blocks, one
block per tip, so block t occupies rows [t*nspots, (t+1)*nspots).
Fields
ngrid_r: usizengrid_c: usizenspot_r: usizenspot_c: usizeTrait Implementations
Sourceimpl Clone for PrinterLayout
impl Clone for PrinterLayout
Sourcefn clone(&self) -> PrinterLayout
fn clone(&self) -> PrinterLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrinterLayout
impl Debug for PrinterLayout
impl Copy for PrinterLayout